import pygame
from pygame.sprite import Sprite

class Alien(Sprite):
    """A class to represent a single alien in the fleet."""

    def __init__(self, ai_settings, screen):
        """Initialize the alien, and set its starting position."""
        super(Alien, self).__init__()
        self.screen = screen
        self.ai_settings = ai_settings

        # Load the alien image, and set its rect attribute.
        self.image = pygame.image.load('resource/alien.bmp')
        self.rect = self.image.get_rect()

        # Start each new alien near the top left of the screen.
        self.rect.x = self.rect.width
        self.rect.y = self.rect.height

        # Store the alien's exact position.
        self.x = float(self.rect.x)
        
    def check_edges(self):
        """Return True if alien is at edge of screen."""
        screen_rect = self.screen.get_rect()
        if self.rect.right >= screen_rect.right:
            return True
        elif self.rect.left <= 0:
            return True
        
    def update(self):
        """Move the alien right or left."""
        self.x += (self.ai_settings.alien_speed_factor *
                        self.ai_settings.fleet_direction)
        self.rect.x = self.x

    def blitme(self):
        """Draw the alien at its current location."""
        self.screen.blit(self.image, self.rect)



import pygame.font
from pygame.sprite import Group

from ship import Ship

class Scoreboard():
    """A class to report scoring information."""

    def __init__(self, ai_settings, screen, stats):
        """Initialize scorekeeping attributes."""
        self.screen = screen
        self.screen_rect = screen.get_rect()
        self.ai_settings = ai_settings
        self.stats = stats
        
        # Font settings for scoring information.
        self.text_color = (30, 30, 30)
        self.font = pygame.font.SysFont(None, 48)

        # Prepare the initial score images.
        self.prep_score()
        self.prep_high_score()
        self.prep_level()
        self.prep_ships()

    def prep_score(self):
        """Turn the score into a rendered image."""
        rounded_score = int(round(self.stats.score, -1))
        score_str = "{:,}".format(rounded_score)
        self.score_image = self.font.render(score_str, True, self.text_color,
            self.ai_settings.bg_color)
            
        # Display the score at the top right of the screen.
        self.score_rect = self.score_image.get_rect()
        self.score_rect.right = self.screen_rect.right - 20
        self.score_rect.top = 20
        
    def prep_high_score(self):
        """Turn the high score into a rendered image."""
        high_score = int(round(self.stats.high_score, -1))
        high_score_str = "{:,}".format(high_score)
        self.high_score_image = self.font.render(high_score_str, True,
            self.text_color, self.ai_settings.bg_color)
                
        # Center the high score at the top of the screen.
        self.high_score_rect = self.high_score_image.get_rect()
        self.high_score_rect.centerx = self.screen_rect.centerx
        self.high_score_rect.top = self.score_rect.top
        
    def prep_level(self):
        """Turn the level into a rendered image."""
        self.level_image = self.font.render(str(self.stats.level), True,
                self.text_color, self.ai_settings.bg_color)
        
        # Position the level below the score.
        self.level_rect = self.level_image.get_rect()
        self.level_rect.right = self.score_rect.right
        self.level_rect.top = self.score_rect.bottom + 10
        
    def prep_ships(self):
        """Show how many ships are left."""
        self.ships = Group()
        for ship_number in range(self.stats.ships_left):
            ship = Ship(self.ai_settings, self.screen)
            ship.rect.x = 10 + ship_number * ship.rect.width
            ship.rect.y = 10
            self.ships.add(ship)
        
    def show_score(self):
        """Draw score to the screen."""
        self.screen.blit(self.score_image, self.score_rect)
        self.screen.blit(self.high_score_image, self.high_score_rect)
        self.screen.blit(self.level_image, self.level_rect)
        # Draw ships.
        self.ships.draw(self.screen)



import random
import pygame
import sys
from pygame.locals import *

print("上下左右键控制 一定要用力 还有开始时要随便选一个键来开启")
Snakespeed = 17
Window_Width = 800
Window_Height = 500
Cell_Size = 20
assert Window_Width % Cell_Size == 0

assert Window_Height % Cell_Size == 0
Cell_W = int(Window_Width / Cell_Size)
Cell_H = int(Window_Height / Cell_Size)

White = (255, 255, 255)
Black = (0, 0, 0)
Red = (255, 0, 0)
Green = (0, 255, 0)
DARKGreen = (0, 155, 0)
DARKGRAY = (40, 40, 40)
YELLOW = (255, 255, 0)
Red_DARK = (150, 0, 0)
BLUE = (0, 0, 255)
BLUE_DARK = (0, 0, 150)

BGCOLOR = Black

UP = 'up'
DOWN = 'down'
LEFT = 'left'
RIGHT = 'right'

HEAD = 0


def main():
    global SnakespeedCLOCK, DISPLAYSURF, BASICFONT

    pygame.init()
    SnakespeedCLOCK = pygame.time.Clock()
    DISPLAYSURF = pygame.display.set_mode((Window_Width, Window_Height))
    BASICFONT = pygame.font.Font('freesansbold.ttf', 18)
    pygame.display.set_caption('snake')

    showStartScreen()
    while True:
        runGame()
        showGameOverScreen()


def runGame():
    startx = random.randint(5, Cell_W - 6)
    starty = random.randint(5, Cell_H - 6)
    wormCoords = [{'x': startx, 'y': starty},
                  {'x': startx - 1, 'y': starty},
                  {'x': startx - 2, 'y': starty}]
    direction = RIGHT

    apple = getRandomLocation()

    while True:
        for event in pygame.event.get():
            if event.type == QUIT:
                terminate()
            elif event.type == KEYDOWN:
                if (event.key == K_LEFT) and direction != RIGHT:
                    direction = LEFT
                elif (event.key == K_RIGHT) and direction != LEFT:
                    direction = RIGHT
                elif (event.key == K_UP) and direction != DOWN:
                    direction = UP
                elif (event.key == K_DOWN) and direction != UP:
                    direction = DOWN
                elif event.key == K_ESCAPE:
                    terminate()

        if wormCoords[HEAD]['x'] == -1 or wormCoords[HEAD]['x'] == Cell_W or wormCoords[HEAD]['y'] == -1 or \
                wormCoords[HEAD]['y'] == Cell_H:
            return
        for wormBody in wormCoords[1:]:
            if wormBody['x'] == wormCoords[HEAD]['x'] and wormBody['y'] == wormCoords[HEAD]['y']:
                return

        if wormCoords[HEAD]['x'] == apple['x'] and wormCoords[HEAD]['y'] == apple['y']:
            apple = getRandomLocation()
        else:
            del wormCoords[-1]

        if direction == UP:
            newHead = {'x': wormCoords[HEAD]['x'],
                       'y': wormCoords[HEAD]['y'] - 1}
        elif direction == DOWN:
            newHead = {'x': wormCoords[HEAD]['x'],
                       'y': wormCoords[HEAD]['y'] + 1}
        elif direction == LEFT:
            newHead = {'x': wormCoords[HEAD][
                                'x'] - 1, 'y': wormCoords[HEAD]['y']}
        elif direction == RIGHT:
            newHead = {'x': wormCoords[HEAD][
                                'x'] + 1, 'y': wormCoords[HEAD]['y']}
        wormCoords.insert(0, newHead)
        DISPLAYSURF.fill(BGCOLOR)
        drawGrid()
        drawWorm(wormCoords)
        drawApple(apple)
        drawScore(len(wormCoords) - 3)
        pygame.display.update()
        SnakespeedCLOCK.tick(Snakespeed)


def drawPressKeyMsg():
    pressKeySurf = BASICFONT.render('Press a key to play.', True, White)
    pressKeyRect = pressKeySurf.get_rect()
    pressKeyRect.topleft = (Window_Width - 200, Window_Height - 30)
    DISPLAYSURF.blit(pressKeySurf, pressKeyRect)


def checkForKeyPress():
    if len(pygame.event.get(QUIT)) > 0:
        terminate()
    keyUpEvents = pygame.event.get(KEYUP)
    if len(keyUpEvents) == 0:
        return None
    if keyUpEvents[0].key == K_ESCAPE:
        terminate()
    return keyUpEvents[0].key


def showStartScreen():
    titleFont = pygame.font.Font('freesansbold.ttf', 100)
    titleSurf1 = titleFont.render('火焰工作室', True, White, DARKGreen)
    degrees1 = 0
    degrees2 = 0
    while True:
        DISPLAYSURF.fill(BGCOLOR)
        rotatedSurf1 = pygame.transform.rotate(titleSurf1, degrees1)
        rotatedRect1 = rotatedSurf1.get_rect()
        rotatedRect1.center = (Window_Width / 2, Window_Height / 2)
        DISPLAYSURF.blit(rotatedSurf1, rotatedRect1)

        drawPressKeyMsg()

        if checkForKeyPress():
            pygame.event.get()
            return
        pygame.display.update()
        SnakespeedCLOCK.tick(Snakespeed)
        degrees1 += 3
        degrees2 += 7


def terminate():
    pygame.quit()
    sys.exit()


def getRandomLocation():
    return {'x': random.randint(0, Cell_W - 1), 'y': random.randint(0, Cell_H - 1)}


def showGameOverScreen():
    gameOverFont = pygame.font.Font('freesansbold.ttf', 100)
    gameSurf = gameOverFont.render('Game', True, White)
    overSurf = gameOverFont.render('Over', True, White)
    gameRect = gameSurf.get_rect()
    overRect = overSurf.get_rect()
    gameRect.midtop = (Window_Width / 2, 10)
    overRect.midtop = (Window_Width / 2, gameRect.height + 10 + 25)

    DISPLAYSURF.blit(gameSurf, gameRect)
    DISPLAYSURF.blit(overSurf, overRect)
    drawPressKeyMsg()
    pygame.display.update()
    pygame.time.wait(500)
    checkForKeyPress()
    while True:
        if checkForKeyPress():
            pygame.event.get()
            return


def drawScore(score):
    scoreSurf = BASICFONT.render('Score: %s' % (score), True, White)
    scoreRect = scoreSurf.get_rect()
    scoreRect.topleft = (Window_Width - 120, 10)
    DISPLAYSURF.blit(scoreSurf, scoreRect)


def drawWorm(wormCoords):
    for coord in wormCoords:
        x = coord['x'] * Cell_Size
        y = coord['y'] * Cell_Size
        wormSegmentRect = pygame.Rect(x, y, Cell_Size, Cell_Size)
        pygame.draw.rect(DISPLAYSURF, DARKGreen, wormSegmentRect)
        wormInnerSegmentRect = pygame.Rect(
            x + 4, y + 4, Cell_Size - 8, Cell_Size - 8)
        pygame.draw.rect(DISPLAYSURF, Green, wormInnerSegmentRect)


def drawApple(coord):
    x = coord['x'] * Cell_Size
    y = coord['y'] * Cell_Size
    appleRect = pygame.Rect(x, y, Cell_Size, Cell_Size)
    pygame.draw.rect(DISPLAYSURF, Red, appleRect)


def drawGrid():
    for x in range(0, Window_Width, Cell_Size):  # draw vertical lines
        pygame.draw.line(DISPLAYSURF, DARKGRAY, (x, 0), (x, Window_Height))
    for y in range(0, Window_Height, Cell_Size):  # draw horizontal lines
        pygame.draw.line(DISPLAYSURF, DARKGRAY, (0, y), (Window_Width, y))


if __name__ == '__main__':
    try:
        main()
    except SystemExit:
        pass



class Settings():
    """A class to store all settings for Alien Invasion."""

    def __init__(self):
        """Initialize the game's static settings."""
        # Screen settings.
        self.screen_width = 1200
        self.screen_height = 800
        self.bg_color = (230, 230, 230)
        
        # Ship settings.
        self.ship_limit = 3
            
        # Bullet settings.
        self.bullet_width = 3
        self.bullet_height = 15
        self.bullet_color = 60, 60, 60
        self.bullets_allowed = 3
        
        # Alien settings.
        self.fleet_drop_speed = 10
            
        # How quickly the game speeds up.
        self.speedup_scale = 1.1
        # How quickly the alien point values increase.
        self.score_scale = 1.5
    
        self.initialize_dynamic_settings()

    def initialize_dynamic_settings(self):
        """Initialize settings that change throughout the game."""
        self.ship_speed_factor = 1.5
        self.bullet_speed_factor = 3
        self.alien_speed_factor = 1
        
        # Scoring.
        self.alien_points = 50
    
        # fleet_direction of 1 represents right, -1 represents left.
        self.fleet_direction = 1
        
    def increase_speed(self):
        """Increase speed settings and alien point values."""
        self.ship_speed_factor *= self.speedup_scale
        self.bullet_speed_factor *= self.speedup_scale
        self.alien_speed_factor *= self.speedup_scale
        
        self.alien_points = int(self.alien_points * self.score_scale)



import pygame
import math
import sys
import time


def hit_the_block():
    class GameWindow:
        """创建游戏窗口类"""

        def __init__(self):
            self.window_length = 600
            self.window_wide = 500
            # 绘制游戏窗口，设置窗口尺寸
            self.game_window = pygame.display.set_mode((self.window_length, self.window_wide))
            # 设置游戏窗口标题
            pygame.display.set_caption("CatchBallGame")
            # 定义游戏窗口背景颜色参数
            self.window_color = (135, 206, 250)

        def backgroud(self):
            # 绘制游戏窗口背景颜色
            self.game_window.fill(self.window_color)

    class Ball:
        """创建球类"""

        def __init__(self):
            # 设置球的半径、颜色、移动速度参数
            self.ball_color = (255, 215, 0)
            self.move_x = 1
            self.move_y = 1
            self.radius = 10

        def ballready(self):
            # 设置球的初始位置、
            self.ball_x = self.mouse_x
            self.ball_y = self.window_wide - self.rect_wide - self.radius
            # 绘制球，设置反弹触发条件
            pygame.draw.circle(self.game_window, self.ball_color, (self.ball_x, self.ball_y), self.radius)

        def ballmove(self):
            # 绘制球，设置反弹触发条件
            pygame.draw.circle(self.game_window, self.ball_color, (self.ball_x, self.ball_y), self.radius)
            self.ball_x += self.move_x
            self.ball_y -= self.move_y
            # 调用碰撞检测函数
            self.ball_window()
            self.ball_rect()
            # 每接5次球球速增加一倍
            if self.distance < self.radius:
                self.frequency += 1
                if self.frequency == 5:
                    self.frequency = 0
                    self.move_x += self.move_x
                    self.move_y += self.move_y
                    self.point += self.point
            # 设置游戏失败条件
            if self.ball_y > 520:
                self.gameover = self.over_font.render("Game Over", False, (0, 0, 0))
                self.game_window.blit(self.gameover, (100, 130))
                self.over_sign = 1

    class Rect:
        # 创建球拍类
        def __init__(self):
            # 设置球拍颜色参数
            self.rect_color = (255, 0, 0)
            self.rect_length = 100
            self.rect_wide = 10

        def rectmove(self):
            # 获取鼠标位置参数
            self.mouse_x, self.mouse_y = pygame.mouse.get_pos()
            # 绘制球拍，限定横向边界
            if self.mouse_x >= self.window_length - self.rect_length // 2:
                self.mouse_x = self.window_length - self.rect_length // 2
            if self.mouse_x <= self.rect_length // 2:
                self.mouse_x = self.rect_length // 2
            pygame.draw.rect(self.game_window, self.rect_color, (
            (self.mouse_x - self.rect_length // 2), (self.window_wide - self.rect_wide), self.rect_length,
            self.rect_wide))

    class Brick:
        def __init__(self):
            # 设置砖块颜色参数
            self.brick_color = (139, 126, 102)
            self.brick_list = [[1, 1, 1, 1, 1, 1], [1, 1, 1, 1, 1, 1], [1, 1, 1, 1, 1, 1], [1, 1, 1, 1, 1, 1],
                               [1, 1, 1, 1, 1, 1]]
            self.brick_length = 80
            self.brick_wide = 20

        def brickarrange(self):
            for i in range(5):
                for j in range(6):
                    self.brick_x = j * (self.brick_length + 24)
                    self.brick_y = i * (self.brick_wide + 20) + 40
                    if self.brick_list[i][j] == 1:
                        # 绘制砖块
                        pygame.draw.rect(self.game_window, self.brick_color,
                                         (self.brick_x, self.brick_y, self.brick_length, self.brick_wide))
                        # 调用碰撞检测函数
                        self.ball_brick()
                        if self.distanceb < self.radius:
                            self.brick_list[i][j] = 0
                            self.score += self.point
            # 设置游戏胜利条件
            if self.brick_list == [[0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0],
                                   [0, 0, 0, 0, 0, 0]]:
                self.win = self.win_font.render("You Win", False, (0, 0, 0))
                self.game_window.blit(self.win, (100, 130))
                self.win_sign = 1

    class Score:
        """创建分数类"""

        def __init__(self):
            # 设置初始分数
            self.score = 0
            # 设置分数字体
            self.score_font = pygame.font.SysFont('arial', 20)
            # 设置初始加分点数
            self.point = 1
            # 设置初始接球次数
            self.frequency = 0

        def countscore(self):
            # 绘制玩家分数
            my_score = self.score_font.render(str(self.score), False, (255, 255, 255))
            self.game_window.blit(my_score, (555, 15))

    class GameOver:
        """创建游戏结束类"""

        def __init__(self):
            # 设置Game Over字体
            self.over_font = pygame.font.SysFont('arial', 80)
            # 定义GameOver标识
            self.over_sign = 0

    class Win:
        """创建游戏胜利类"""

        def __init__(self):
            # 设置You Win字体
            self.win_font = pygame.font.SysFont('arial', 80)
            # 定义Win标识
            self.win_sign = 0

    class Collision:
        """碰撞检测类"""

        # 球与窗口边框的碰撞检测
        def ball_window(self):
            if self.ball_x <= self.radius or self.ball_x >= (self.window_length - self.radius):
                self.move_x = -self.move_x
            if self.ball_y <= self.radius:
                self.move_y = -self.move_y

        # 球与球拍的碰撞检测
        def ball_rect(self):
            # 定义碰撞标识
            self.collision_sign_x = 0
            self.collision_sign_y = 0

            if self.ball_x < (self.mouse_x - self.rect_length // 2):
                self.closestpoint_x = self.mouse_x - self.rect_length // 2
                self.collision_sign_x = 1
            elif self.ball_x > (self.mouse_x + self.rect_length // 2):
                self.closestpoint_x = self.mouse_x + self.rect_length // 2
                self.collision_sign_x = 2
            else:
                self.closestpoint_x = self.ball_x
                self.collision_sign_x = 3

            if self.ball_y < (self.window_wide - self.rect_wide):
                self.closestpoint_y = (self.window_wide - self.rect_wide)
                self.collision_sign_y = 1
            elif self.ball_y > self.window_wide:
                self.closestpoint_y = self.window_wide
                self.collision_sign_y = 2
            else:
                self.closestpoint_y = self.ball_y
                self.collision_sign_y = 3
            # 定义球拍到圆心最近点与圆心的距离
            self.distance = math.sqrt(
                math.pow(self.closestpoint_x - self.ball_x, 2) + math.pow(self.closestpoint_y - self.ball_y, 2))
            # 球在球拍上左、上中、上右3种情况的碰撞检测
            if self.distance < self.radius and self.collision_sign_y == 1 and (
                    self.collision_sign_x == 1 or self.collision_sign_x == 2):
                if self.collision_sign_x == 1 and self.move_x > 0:
                    self.move_x = - self.move_x
                    self.move_y = - self.move_y
                if self.collision_sign_x == 1 and self.move_x < 0:
                    self.move_y = - self.move_y
                if self.collision_sign_x == 2 and self.move_x < 0:
                    self.move_x = - self.move_x
                    self.move_y = - self.move_y
                if self.collision_sign_x == 2 and self.move_x > 0:
                    self.move_y = - self.move_y
            if self.distance < self.radius and self.collision_sign_y == 1 and self.collision_sign_x == 3:
                self.move_y = - self.move_y
            # 球在球拍左、右两侧中间的碰撞检测
            if self.distance < self.radius and self.collision_sign_y == 3:
                self.move_x = - self.move_x

        # 球与砖块的碰撞检测
        def ball_brick(self):
            # 定义碰撞标识
            self.collision_sign_bx = 0
            self.collision_sign_by = 0

            if self.ball_x < self.brick_x:
                self.closestpoint_bx = self.brick_x
                self.collision_sign_bx = 1
            elif self.ball_x > self.brick_x + self.brick_length:
                self.closestpoint_bx = self.brick_x + self.brick_length
                self.collision_sign_bx = 2
            else:
                self.closestpoint_bx = self.ball_x
                self.collision_sign_bx = 3

            if self.ball_y < self.brick_y:
                self.closestpoint_by = self.brick_y
                self.collision_sign_by = 1
            elif self.ball_y > self.brick_y + self.brick_wide:
                self.closestpoint_by = self.brick_y + self.brick_wide
                self.collision_sign_by = 2
            else:
                self.closestpoint_by = self.ball_y
                self.collision_sign_by = 3
            # 定义砖块到圆心最近点与圆心的距离
            self.distanceb = math.sqrt(
                math.pow(self.closestpoint_bx - self.ball_x, 2) + math.pow(self.closestpoint_by - self.ball_y, 2))
            # 球在砖块上左、上中、上右3种情况的碰撞检测
            if self.distanceb < self.radius and self.collision_sign_by == 1 and (
                    self.collision_sign_bx == 1 or self.collision_sign_bx == 2):
                if self.collision_sign_bx == 1 and self.move_x > 0:
                    self.move_x = - self.move_x
                    self.move_y = - self.move_y
                if self.collision_sign_bx == 1 and self.move_x < 0:
                    self.move_y = - self.move_y
                if self.collision_sign_bx == 2 and self.move_x < 0:
                    self.move_x = - self.move_x
                    self.move_y = - self.move_y
                if self.collision_sign_bx == 2 and self.move_x > 0:
                    self.move_y = - self.move_y
            if self.distanceb < self.radius and self.collision_sign_by == 1 and self.collision_sign_bx == 3:
                self.move_y = - self.move_y
            # 球在砖块下左、下中、下右3种情况的碰撞检测
            if self.distanceb < self.radius and self.collision_sign_by == 2 and (
                    self.collision_sign_bx == 1 or self.collision_sign_bx == 2):
                if self.collision_sign_bx == 1 and self.move_x > 0:
                    self.move_x = - self.move_x
                    self.move_y = - self.move_y
                if self.collision_sign_bx == 1 and self.move_x < 0:
                    self.move_y = - self.move_y
                if self.collision_sign_bx == 2 and self.move_x < 0:
                    self.move_x = - self.move_x
                    self.move_y = - self.move_y
                if self.collision_sign_bx == 2 and self.move_x > 0:
                    self.move_y = - self.move_y
            if self.distanceb < self.radius and self.collision_sign_by == 2 and self.collision_sign_bx == 3:
                self.move_y = - self.move_y
            # 球在砖块左、右两侧中间的碰撞检测
            if self.distanceb < self.radius and self.collision_sign_by == 3:
                self.move_x = - self.move_x

    class Main(GameWindow, Rect, Ball, Brick, Collision, Score, Win, GameOver):
        """创建主程序类"""

        def __init__(self):
            super(Main, self).__init__()
            super(GameWindow, self).__init__()
            super(Rect, self).__init__()
            super(Ball, self).__init__()
            super(Brick, self).__init__()
            super(Collision, self).__init__()
            super(Score, self).__init__()
            super(Win, self).__init__()
            # 定义游戏开始标识
            start_sign = 0

            while True:
                self.backgroud()
                self.rectmove()
                self.countscore()

                if self.over_sign == 1 or self.win_sign == 1:
                    break
                # 获取游戏窗口状态
                for event in pygame.event.get():
                    if event.type == pygame.QUIT:
                        sys.exit()
                    if event.type == pygame.MOUSEBUTTONDOWN:
                        pressed_array = pygame.mouse.get_pressed()
                        if pressed_array[0]:
                            start_sign = 1
                if start_sign == 0:
                    self.ballready()
                else:
                    self.ballmove()

                self.brickarrange()

                # 更新游戏窗口
                pygame.display.update()
                # 控制游戏窗口刷新频率
                time.sleep(0.010)

    if __name__ == '__main__':
        pygame.init()
        pygame.font.init()
        catchball = Main()

# hit_the_block()



import arcade as ac
from arcade import*
import random


# 大鱼吃小鱼游戏
WIDTH = 1200
HEIGHT = 800
TITLE = '大鱼吃小鱼'
SPEED = 5
LEFT = 0
RIGHT = 1


class Player(Sprite):
    def __init__(self, image):
        super().__init__(image)
        self.center_x = WIDTH // 2
        self.center_y = HEIGHT // 2
        self.append_texture(load_texture('resource/player.png', mirrored=True))
        self.size = 2
        self.level = 0
        self.upgrade = [10, 40, 130]

    def update(self):
        super().update()
        if self.left < 0:
            self.left = 0
        elif self.right > WIDTH:
            self.right = WIDTH

        if self.top > HEIGHT:
            self.top = HEIGHT
        elif self.bottom < 0:
            self.bottom = 0

    def evolution(self, score):
        if score >= self.upgrade[2]:
            self.size = 8
            self.scale = 1.5
        elif score >= self.upgrade[1]:
            self.size = 6
            self.scale = 1.3
            self.level = self.upgrade[2]
        elif score >= self.upgrade[0]:
            self.size = 4
            self.scale = 1.175
            self.level = self.upgrade[1]
        else:
            self.level = self.upgrade[0]


class Enemy(Sprite):
    def __init__(self, image):
        super().__init__(image)
        face = random.choice(['left', 'right'])
        speed = random.choice([1, 2, 3, 4, 5])
        if face == 'left':
            self.center_x = WIDTH + 60
            self.change_x = -speed
        elif face == 'right':
            self.center_x = -60
            self.append_texture(load_texture(image, mirrored=True))
            self.set_texture(RIGHT)
            self.change_x = speed
        self.center_y = random.randint(0, HEIGHT)


class Status(Sprite):
    def __init__(self, image):
        super().__init__(image)
        self.center_x = WIDTH // 2
        self.center_y = HEIGHT // 2


class Game(Window):
    def __init__(self, width, height, title):
        super().__init__(width, height, title)
        self.setup()

    def setup(self):
        self.bg = Sprite('resource/newsea.png')
        self.bg.center_x = WIDTH // 2
        self.bg.center_y = HEIGHT // 2
        self.color = ["yellow", "green", "red", "purple", "blue"]
        self.fishes = ['resource/{}_fish.png'.format(self.color[i]) for i in range(5)]
        self.sizes = [1, 3, 5, 7, 9]
        self.enemy_list = SpriteList()
        self.player = Player("resource/player.png")
        self.total_time = 0
        self.last_time = 0
        self.create_num = 1
        self.player_list = SpriteList()
        self.player_list.append(self.player)
        self.score = 0
        self.game_over_status = False
        self.game_over = Status('resource/game_over.png')
        self.game_pause_status = False
        self.game_pause = Status('resource/game_pause.png')
        self.achievement = 300
        self.achieve_goal = False
        self.eat_sound = load_sound('resource/eat_sound.wav')
        self.game_over_sound = load_sound('resource/game_over_sound.wav')

    def on_draw(self):
        start_render()
        self.bg.draw()
        self.player_list.draw()
        self.enemy_list.draw()
        draw_text(f'分数：{self.score}', 0, HEIGHT - 25, ac.color.WHITE,
                  font_name=('simhei', 'PingFang'), font_size=20)
        draw_text(f'目标：达到{self.achievement}积分', 125, HEIGHT - 25, ac.color.WHITE,
                  font_name=('simhei', 'PingFang'), font_size=20)
        self.upgrade_till_next_level()
        if self.game_over_status:
            self.game_over.draw()
            if int(self.total_time) % 2 == 0:
                draw_text('按下 Tab 键重新开始游戏', WIDTH // 2 - 150, HEIGHT // 2 - 200, 
                          ac.color.WHITE, font_name=('simhei', 'PingFang'), font_size=20)

        if self.game_pause_status:
            self.game_pause.draw()
    
    def on_update(self, delta_time):
        self.total_time += delta_time
        if self.game_over_status or self.game_pause_status or self.achieve_goal:
            return

        if int(self.total_time) != int(self.last_time) and int(self.total_time) % 300 == 0:
            self.create_num += 1
        
        if int(self.total_time) != int(self.last_time) and int(self.total_time) % 1 == 0:
            self.create_enemy()
            self.last_time = self.total_time

        self.player_list.update()
        self.enemy_list.update()
        for enemy in self.enemy_list:
            if enemy.center_x < -60 or enemy.center_x > WIDTH + 60:
                enemy.kill()
        
        hit_list = check_for_collision_with_list(self.player, self.enemy_list)
        if hit_list:
            for hit in hit_list:
                if self.player.size > hit.size:
                    play_sound(self.eat_sound)
                    hit.kill()
                    self.score += (hit.size + 1) // 2
                else:
                    self.player.kill()
                    play_sound(self.game_over_sound)
                    self.game_over_status = True

        self.player.evolution(self.score)

    def on_key_press(self, symbol, modifiers):
        if symbol == ac.key.UP:
            self.player.change_y = SPEED
        
        elif symbol == ac.key.DOWN:
            self.player.change_y = -SPEED
        
        elif symbol == ac.key.LEFT:
            self.player.change_x = -SPEED
            self.player.set_texture(LEFT)
        
        elif symbol == ac.key.RIGHT:
            self.player.change_x = SPEED
            self.player.set_texture(RIGHT)
        
        elif symbol == ac.key.RETURN:
            image = get_image(0, 0, WIDTH, HEIGHT)
            image.save('screenshot.png')
        
        elif symbol == ac.key.ESCAPE:
            self.game_pause_status = not self.game_pause_status
    
        elif symbol == ac.key.TAB:
            if self.game_over_status:
                self.setup()

    def on_key_release(self, symbol, modifiers):
        if symbol == ac.key.UP or symbol == ac.key.DOWN:
            self.player.change_y = 0
        elif symbol == ac.key.LEFT or symbol == ac.key.RIGHT:
            self.player.change_x = 0

    def upgrade_till_next_level(self):
        if self.player.level >= self.score:
            draw_text(f'距离下一等级还差{self.player.level - self.score}分', 350, HEIGHT - 25,
                      ac.color.WHITE, font_name=('simhei', 'PingFang'), font_size=20)
        
        elif self.player.upgrade[2] < self.score < self.achievement:
            draw_text(f'距离达成目标还差{self.achievement - self.score}分', 350, HEIGHT - 25,
                      ac.color.WHITE, font_name=('simhei', 'PingFang'), font_size=20)
        
        elif self.score >= self.achievement:
            draw_text('目标达成！', WIDTH // 2 - 210, HEIGHT // 2 - 50, ac.color.RED,
                      font_name=('simhei', 'PingFang'), font_size=80)
            self.achieve_goal = True

    def create_enemy(self):
        for i in range(self.create_num):
            fish = random.choices(self.fishes, [0.3, 0.15, 0.125, 0.125, 0.3])[0]
            size = self.sizes[self.fishes.index(fish)]
            enemy = Enemy(fish)
            enemy.size = size
            self.enemy_list.append(enemy)


def run_game():
    game = Game(WIDTH, HEIGHT, TITLE)
    run()


run_game()



import pygame
from pygame.sprite import Sprite

class Bullet(Sprite):
    """A class to manage bullets fired from the ship."""

    def __init__(self, ai_settings, screen, ship):
        """Create a bullet object, at the ship's current position."""
        super(Bullet, self).__init__()
        self.screen = screen

        # Create bullet rect at (0, 0), then set correct position.
        self.rect = pygame.Rect(0, 0, ai_settings.bullet_width,
            ai_settings.bullet_height)
        self.rect.centerx = ship.rect.centerx
        self.rect.top = ship.rect.top
        
        # Store a decimal value for the bullet's position.
        self.y = float(self.rect.y)

        self.color = ai_settings.bullet_color
        self.speed_factor = ai_settings.bullet_speed_factor

    def update(self):
        """Move the bullet up the screen."""
        # Update the decimal position of the bullet.
        self.y -= self.speed_factor
        # Update the rect position.
        self.rect.y = self.y

    def draw_bullet(self):
        """Draw the bullet to the screen."""
        pygame.draw.rect(self.screen, self.color, self.rect)



import pygame.font

class Button():

    def __init__(self, ai_settings, screen, msg):
        """Initialize button attributes."""
        self.screen = screen
        self.screen_rect = screen.get_rect()
        
        # Set the dimensions and properties of the button.
        self.width, self.height = 200, 50
        self.button_color = (0, 255, 0)
        self.text_color = (255, 255, 255)
        self.font = pygame.font.SysFont(None, 48)
        
        # Build the button's rect object, and center it.
        self.rect = pygame.Rect(0, 0, self.width, self.height)
        self.rect.center = self.screen_rect.center
        
        # The button message only needs to be prepped once.
        self.prep_msg(msg)

    def prep_msg(self, msg):
        """Turn msg into a rendered image, and center text on the button."""
        self.msg_image = self.font.render(msg, True, self.text_color,
            self.button_color)
        self.msg_image_rect = self.msg_image.get_rect()
        self.msg_image_rect.center = self.rect.center
        
    def draw_button(self):
        # Draw blank button, then draw message.
        self.screen.fill(self.button_color, self.rect)
        self.screen.blit(self.msg_image, self.msg_image_rect)



import arcade as ac
from arcade import*
import json
import random


SCREEN_WIDTH = 600
SCREEN_HEIGHT = 800
SCREEN_TITLE = "冒险小车"


class Road(Sprite):
    def __init__(self, image):
        super().__init__(image)
        # 车道
        self.center_x = SCREEN_WIDTH//2
        self.center_y = SCREEN_HEIGHT//2
        self.change_y = -9

    def update(self):
        super().update()
        if self.center_y <= SCREEN_HEIGHT // 2 - SCREEN_HEIGHT:
            self.center_y = SCREEN_HEIGHT // 2 + SCREEN_HEIGHT


class SmallCar(Sprite):
    def __init__(self, image):
        super().__init__(image)
        # 小车
        self.center_x = SCREEN_WIDTH // 2
        self.center_y = 100

    def update(self):
        super().update()


class Cart(Sprite):
    def __init__(self, image):
        super().__init__(image)
        self.center_y = random.randint(SCREEN_HEIGHT, SCREEN_HEIGHT + SCREEN_HEIGHT // 2)
        self.change_y = -2


class GameOver(Sprite):
    def __init__(self, image):
        super().__init__(image)
        self.center_x = SCREEN_WIDTH // 2
        self.center_y = SCREEN_HEIGHT // 2


class StatusBar():
    def __init__(self):
        self.distance = 0
        self.hp = 2
        with open("resource/score.json", "r") as self.f:
            self.data = json.load(self.f)
            self.top_score = self.data["score"]

    def draw_top_score(self):
        pos_x = SCREEN_WIDTH - 100
        pos_y = SCREEN_HEIGHT - 20
        draw_text(f"最高分：{self.top_score}", pos_x, pos_y, ac.color.BLUE, font_name=("simhei", "PingFang"))


    def draw_bar(self):
        draw_rectangle_filled(
            SCREEN_WIDTH // 2, SCREEN_HEIGHT - 15, SCREEN_WIDTH, 30, ac.color.WHITE
        )
    
    def draw_distance(self):
        pos_x = 10
        pos_y = SCREEN_HEIGHT - 20
        draw_text(f"路程：{self.distance}", pos_x, pos_y, ac.color.BLUE, font_name=("simhei", "PingFang"))
    
    def draw_hp(self):
        pos_x = SCREEN_WIDTH//2 - 50
        pos_y = SCREEN_HEIGHT - 20
        draw_text(f"血量：", pos_x, pos_y, ac.color.BLUE, font_name=("simhei", "PingFang"))
        hearts = SpriteList()
        for i in range(self.hp):
            heart = Sprite("resource/heal.png")
            heart.center_x = pos_x + 50 + heart.width*i
            heart.center_y = pos_y + 5
            hearts.append(heart)
        hearts.draw()
            

class MyCar(Window):
    def __init__(self, width, height, title):
        super().__init__(width, height, title)
        self.setup()

    def setup(self):
        self.road1 = Road("resource/road.png")
        self.road2 = Road("resource/road.png")
        self.road2.center_y = SCREEN_HEIGHT // 2 + SCREEN_HEIGHT
        self.small_car_list = [f"resource/small_car{str(i)}" for i in range(1, 5)]
        self.small_car = SmallCar(f"{random.choice(self.small_car_list)}.png")
        self.carts = SpriteList()
        self.create_carts()
        self.total_time = 0
        self.last_time = 0
        self.status_bar = StatusBar()
        self.game_status = True
        self.gameover = GameOver("resource/gameover.png")

    def on_draw(self):
        start_render()
        self.road1.draw()
        self.road2.draw()
        self.small_car.draw()
        for cart in self.carts:
            cart.draw()
        self.status_bar.draw_bar()
        self.status_bar.draw_distance()
        self.status_bar.draw_hp()
        if not self.game_status:
            self.gameover.draw()
        self.status_bar.draw_top_score()

    def on_update(self, delta_time: float):
        if self.game_status:
            self.small_car.update()
            self.road1.update()
            self.road2.update()
            for cart in self.carts:
                cart.update()
                if cart.top < 0:
                    cart.kill()
            self.total_time += delta_time
            if int(self.last_time) != int(self.total_time) and int(self.total_time) % 6 == 0:
                self.create_carts()
                self.last_time = self.total_time
            self.status_bar.distance = int(self.total_time)
            hit_list = check_for_collision_with_list(self.small_car, self.carts)
            if hit_list:
                for hit in hit_list:
                    hit.kill()
                    self.status_bar.hp -= 1
            self.judge_game_status()

    def on_key_release(self, symbol: int, modifiers: int):
        if symbol == ac.key.LEFT and self.small_car.center_x >= SCREEN_WIDTH //2:
            self.small_car.center_x -= 200
        elif symbol == ac.key.RIGHT and self.small_car.center_x <= SCREEN_WIDTH //2:
            self.small_car.center_x += 200

    def create_carts(self):
        cart_list = ["resource/big_car1.png", "resource/big_car2.png", "resource/big_car3.png"]
        num = 2
        x = random.sample([SCREEN_WIDTH // 2 - 200, SCREEN_WIDTH // 2, SCREEN_WIDTH // 2 + 200], 2)
        for i in range(num):
            cart = Cart(random.choice(cart_list))
            cart.center_x = x[i]
            self.carts.append(cart)

    def judge_game_status(self):
        if self.status_bar.hp <= 0:
            self.game_status = False
            if self.status_bar.distance > self.status_bar.top_score:
                self.status_bar.data["score"] = self.status_bar.distance
                with open("resource/score.json", "w") as f:
                    json.dump(self.status_bar.data, f)


def run_game():
    game = MyCar(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_TITLE)
    run()


# run_game()



class GameStats():
    """Track statistics for Alien Invasion."""
    
    def __init__(self, ai_settings):
        """Initialize statistics."""
        self.ai_settings = ai_settings
        self.reset_stats()
        
        # Start game in an inactive state.
        self.game_active = False
        
        # High score should never be reset.
        self.high_score = 0
        
    def reset_stats(self):
        """Initialize statistics that can change during the game."""
        self.ships_left = self.ai_settings.ship_limit
        self.score = 0
        self.level = 1



import pygame
from pygame.sprite import Group
from settings import Settings
from game_stats import GameStats
from scoreboard import Scoreboard
from button import Button
from ship import Ship
import game_functions as gf


def run_game():
    # Initialize pygame, settings, and screen object.
    pygame.init()
    ai_settings = Settings()
    screen = pygame.display.set_mode(
        (ai_settings.screen_width, ai_settings.screen_height))
    pygame.display.set_caption("Alien Invasion")
    
    # Make the Play button.
    play_button = Button(ai_settings, screen, "Play")
    
    # Create an instance to store game statistics, and a scoreboard.
    stats = GameStats(ai_settings)
    sb = Scoreboard(ai_settings, screen, stats)
    
    # Set the background color.
    bg_color = (230, 230, 230)
    
    # Make a ship, a group of bullets, and a group of aliens.
    ship = Ship(ai_settings, screen)
    bullets = Group()
    aliens = Group()
    
    # Create the fleet of aliens.
    gf.create_fleet(ai_settings, screen, ship, aliens)

    # Start the main loop for the game.
    while True:
        gf.check_events(ai_settings, screen, stats, sb, play_button, ship,
            aliens, bullets)
        
        if stats.game_active:
            ship.update()
            gf.update_bullets(ai_settings, screen, stats, sb, ship, aliens,
                bullets)
            gf.update_aliens(ai_settings, screen, stats, sb, ship, aliens,
                bullets)
        
        gf.update_screen(ai_settings, screen, stats, sb, ship, aliens,
            bullets, play_button)


# run_game()



import pygame
from pygame.sprite import Sprite


class Ship(Sprite):
    def __init__(self, ai_settings, screen):
        """Initialize the ship, and set its starting position."""
        super(Ship, self).__init__()
        self.screen = screen
        self.ai_settings = ai_settings

        # Load the ship image, and get its rect.
        self.image = pygame.image.load('resource/ship.bmp')
        self.rect = self.image.get_rect()
        self.screen_rect = screen.get_rect()

        # Start each new ship at the bottom center of the screen.
        self.rect.centerx = self.screen_rect.centerx
        self.rect.bottom = self.screen_rect.bottom
        
        # Store a decimal value for the ship's center.
        self.center = float(self.rect.centerx)
        
        # Movement flags.
        self.moving_right = False
        self.moving_left = False
        
    def center_ship(self):
        """Center the ship on the screen."""
        self.center = self.screen_rect.centerx
        
    def update(self):
        """Update the ship's position, based on movement flags."""
        # Update the ship's center value, not the rect.
        if self.moving_right and self.rect.right < self.screen_rect.right:
            self.center += self.ai_settings.ship_speed_factor
        if self.moving_left and self.rect.left > 0:
            self.center -= self.ai_settings.ship_speed_factor
            
        # Update rect object from self.center.
        self.rect.centerx = self.center

    def blitme(self):
        """Draw the ship at its current location."""
        self.screen.blit(self.image, self.rect)



import sys
from time import sleep

import pygame

from bullet import Bullet
from alien import Alien


def check_keydown_events(event, ai_settings, screen, ship, bullets):
    """Respond to keypresses."""
    if event.key == pygame.K_RIGHT:
        ship.moving_right = True
    elif event.key == pygame.K_LEFT:
        ship.moving_left = True
    elif event.key == pygame.K_SPACE:
        fire_bullet(ai_settings, screen, ship, bullets)
    elif event.key == pygame.K_q:
        sys.exit()


def check_keyup_events(event, ship):
    """Respond to key releases."""
    if event.key == pygame.K_RIGHT:
        ship.moving_right = False
    elif event.key == pygame.K_LEFT:
        ship.moving_left = False


def check_events(ai_settings, screen, stats, sb, play_button, ship, aliens,
        bullets):
    """Respond to keypresses and mouse events."""
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            sys.exit()
        elif event.type == pygame.KEYDOWN:
            check_keydown_events(event, ai_settings, screen, ship, bullets)
        elif event.type == pygame.KEYUP:
            check_keyup_events(event, ship)
        elif event.type == pygame.MOUSEBUTTONDOWN:
            mouse_x, mouse_y = pygame.mouse.get_pos()
            check_play_button(ai_settings, screen, stats, sb, play_button,
                ship, aliens, bullets, mouse_x, mouse_y)


def check_play_button(ai_settings, screen, stats, sb, play_button, ship,
        aliens, bullets, mouse_x, mouse_y):
    """Start a new game when the player clicks Play."""
    button_clicked = play_button.rect.collidepoint(mouse_x, mouse_y)
    if button_clicked and not stats.game_active:
        # Reset the game settings.
        ai_settings.initialize_dynamic_settings()
        
        # Hide the mouse cursor.
        pygame.mouse.set_visible(False)
        
        # Reset the game statistics.
        stats.reset_stats()
        stats.game_active = True
        
        # Reset the scoreboard images.
        sb.prep_score()
        sb.prep_high_score()
        sb.prep_level()
        sb.prep_ships()
        
        # Empty the list of aliens and bullets.
        aliens.empty()
        bullets.empty()
        
        # Create a new fleet and center the ship.
        create_fleet(ai_settings, screen, ship, aliens)
        ship.center_ship()


def fire_bullet(ai_settings, screen, ship, bullets):
    """Fire a bullet, if limit not reached yet."""
    # Create a new bullet, add to bullets group.
    if len(bullets) < ai_settings.bullets_allowed:
        new_bullet = Bullet(ai_settings, screen, ship)
        bullets.add(new_bullet)


def update_screen(ai_settings, screen, stats, sb, ship, aliens, bullets,
        play_button):
    """Update images on the screen, and flip to the new screen."""
    # Redraw the screen, each pass through the loop.
    screen.fill(ai_settings.bg_color)
    
    # Redraw all bullets, behind ship and aliens.
    for bullet in bullets.sprites():
        bullet.draw_bullet()
    ship.blitme()
    aliens.draw(screen)
    
    # Draw the score information.
    sb.show_score()
    
    # Draw the play button if the game is inactive.
    if not stats.game_active:
        play_button.draw_button()

    # Make the most recently drawn screen visible.
    pygame.display.flip()


def update_bullets(ai_settings, screen, stats, sb, ship, aliens, bullets):
    """Update position of bullets, and get rid of old bullets."""
    # Update bullet positions.
    bullets.update()

    # Get rid of bullets that have disappeared.
    for bullet in bullets.copy():
        if bullet.rect.bottom <= 0:
            bullets.remove(bullet)
            
    check_bullet_alien_collisions(ai_settings, screen, stats, sb, ship,
        aliens, bullets)


def check_high_score(stats, sb):
    """Check to see if there's a new high score."""
    if stats.score > stats.high_score:
        stats.high_score = stats.score
        sb.prep_high_score()


def check_bullet_alien_collisions(ai_settings, screen, stats, sb, ship,
        aliens, bullets):
    """Respond to bullet-alien collisions."""
    # Remove any bullets and aliens that have collided.
    collisions = pygame.sprite.groupcollide(bullets, aliens, True, True)
    
    if collisions:
        for aliens in collisions.values():
            stats.score += ai_settings.alien_points * len(aliens)
            sb.prep_score()
        check_high_score(stats, sb)
    
    if len(aliens) == 0:
        # If the entire fleet is destroyed, start a new level.
        bullets.empty()
        ai_settings.increase_speed()
        
        # Increase level.
        stats.level += 1
        sb.prep_level()
        
        create_fleet(ai_settings, screen, ship, aliens)


def check_fleet_edges(ai_settings, aliens):
    """Respond appropriately if any aliens have reached an edge."""
    for alien in aliens.sprites():
        if alien.check_edges():
            change_fleet_direction(ai_settings, aliens)
            break


def change_fleet_direction(ai_settings, aliens):
    """Drop the entire fleet, and change the fleet's direction."""
    for alien in aliens.sprites():
        alien.rect.y += ai_settings.fleet_drop_speed
    ai_settings.fleet_direction *= -1


def ship_hit(ai_settings, screen, stats, sb, ship, aliens, bullets):
    """Respond to ship being hit by alien."""
    if stats.ships_left > 0:
        # Decrement ships_left.
        stats.ships_left -= 1
        
        # Update scoreboard.
        sb.prep_ships()
        
    else:
        stats.game_active = False
        pygame.mouse.set_visible(True)
    
    # Empty the list of aliens and bullets.
    aliens.empty()
    bullets.empty()
    
    # Create a new fleet, and center the ship.
    create_fleet(ai_settings, screen, ship, aliens)
    ship.center_ship()
    
    # Pause.
    sleep(0.5)


def check_aliens_bottom(ai_settings, screen, stats, sb, ship, aliens,
        bullets):
    """Check if any aliens have reached the bottom of the screen."""
    screen_rect = screen.get_rect()
    for alien in aliens.sprites():
        if alien.rect.bottom >= screen_rect.bottom:
            # Treat this the same as if the ship got hit.
            ship_hit(ai_settings, screen, stats, sb, ship, aliens, bullets)
            break


def update_aliens(ai_settings, screen, stats, sb, ship, aliens, bullets):
    """
    Check if the fleet is at an edge,
      then update the postions of all aliens in the fleet.
    """
    check_fleet_edges(ai_settings, aliens)
    aliens.update()
    
    # Look for alien-ship collisions.
    if pygame.sprite.spritecollideany(ship, aliens):
        ship_hit(ai_settings, screen, stats, sb, ship, aliens, bullets)

    # Look for aliens hitting the bottom of the screen.
    check_aliens_bottom(ai_settings, screen, stats, sb, ship, aliens, bullets)


def get_number_aliens_x(ai_settings, alien_width):
    """Determine the number of aliens that fit in a row."""
    available_space_x = ai_settings.screen_width - 2 * alien_width
    number_aliens_x = int(available_space_x / (2 * alien_width))
    return number_aliens_x


def get_number_rows(ai_settings, ship_height, alien_height):
    """Determine the number of rows of aliens that fit on the screen."""
    available_space_y = (ai_settings.screen_height -
                            (3 * alien_height) - ship_height)
    number_rows = int(available_space_y / (2 * alien_height))
    return number_rows


def create_alien(ai_settings, screen, aliens, alien_number, row_number):
    """Create an alien, and place it in the row."""
    alien = Alien(ai_settings, screen)
    alien_width = alien.rect.width
    alien.x = alien_width + 2 * alien_width * alien_number
    alien.rect.x = alien.x
    alien.rect.y = alien.rect.height + 2 * alien.rect.height * row_number
    aliens.add(alien)


def create_fleet(ai_settings, screen, ship, aliens):
    """Create a full fleet of aliens."""
    # Create an alien, and find number of aliens in a row.
    alien = Alien(ai_settings, screen)
    number_aliens_x = get_number_aliens_x(ai_settings, alien.rect.width)
    number_rows = get_number_rows(ai_settings, ship.rect.height,
        alien.rect.height)
    
    # Create the fleet of aliens.
    for row_number in range(number_rows):
        for alien_number in range(number_aliens_x):
            create_alien(ai_settings, screen, aliens, alien_number,
                row_number)



import setuptools

setuptools.setup(
    name="NightWindGameLib",
    version="0.0.8",
    author="Nova_NightWind0311",
    author_email="",
    descripiton="Some little games",
    long_escription_content_type="text/markdown",
    url="https://github.com/",
    include_package_data=True,
    packages=setuptools.find_packages(),
    insatll_requires=[
        "arcade>=2.5.1",
        "pymunk<=5.7.0",
        "pygame>=2.0.0"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
